"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const FONT_FAMILY = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
  forgiving: true,
  simulation: true,
  cache: new Map()
});
function processThemeTokenColors(theme) {
  const tokenColorMap = new Map();
  if (!theme.tokenColors) {
    console.warn('Theme does not contain tokenColors');
    return tokenColorMap;
  }

  // Sort and process the token colors
  const sortedTokenColors = [...theme.tokenColors].sort((a, b) => {
    const aScope = Array.isArray(a.scope) ? a.scope[0] : a.scope ?? '';
    const bScope = Array.isArray(b.scope) ? b.scope[0] : b.scope ?? '';
    return (bScope?.split('.').length || 0) - (aScope?.split('.').length || 0);
  });
  sortedTokenColors.forEach(tokenColor => {
    if (!tokenColor.scope || !tokenColor.settings) {
      console.info('Skipping tokenColor due to missing scope/settings:', tokenColor);
      return;
    }
    const scopes = Array.isArray(tokenColor.scope) ? tokenColor.scope : [tokenColor.scope];
    scopes.forEach(scope => {
      if (!scope) return;
      const scopeParts = scope.split(/[\s,]+/).filter(Boolean);
      scopeParts.forEach(part => {
        if (!tokenColorMap.has(part)) {
          console.log(`Mapping ${part} to color:`, tokenColor.settings.foreground);
          tokenColorMap.set(part, {
            foreground: tokenColor.settings.foreground,
            fontStyle: tokenColor.settings.fontStyle
          });
        }
      });
    });
  });
  return tokenColorMap;
}
function parseColor(color) {
  if (!color) return undefined;

  // Remove any whitespace and standardize format
  color = color.trim().toLowerCase();

  // Handle rgba/rgb format
  if (color.startsWith('rgb')) return color;

  // Handle hex colors
  if (color.startsWith('#')) {
    // Convert 3-digit hex to 6-digit
    if (color.length === 4) {
      const r = color[1];
      const g = color[2];
      const b = color[3];
      return `#${r}${r}${g}${g}${b}${b}`;
    }

    // Handle 8-digit hex (with alpha)
    if (color.length === 9) {
      const r = Number.parseInt(color.slice(1, 3), 16);
      const g = Number.parseInt(color.slice(3, 5), 16);
      const b = Number.parseInt(color.slice(5, 7), 16);
      const a = (Number.parseInt(color.slice(7, 9), 16) / 255).toFixed(2);
      return `rgba(${r}, ${g}, ${b}, ${a})`;
    }

    // Handle 6-digit hex
    if (color.length === 7) {
      const r = Number.parseInt(color.slice(1, 3), 16);
      const g = Number.parseInt(color.slice(3, 5), 16);
      const b = Number.parseInt(color.slice(5, 7), 16);
      return `rgb(${r}, ${g}, ${b})`;
    }
  }
  return color;
}
async function createHighlighter({
  langs,
  themes
}) {
  if (!langs?.length) {
    throw new Error('Please provide languages when creating a highlighter.');
  }
  try {
    const highlighter = await (0, _core.createHighlighterCore)({
      langs,
      themes,
      engine
    });
    return highlighter;
  } catch (error) {
    console.error('Failed to create highlighter:', error);
    throw error;
  }
}
// Token component moved outside SyntaxHighlighter
const Token = /*#__PURE__*/_react.default.memo(({
  token,
  fontSize,
  textStyle,
  baseStyle,
  tokenColorMap
}) => {
  const tokenStyle = (0, _react.useMemo)(() => {
    let tokenForeground;
    let tokenFontStyle;

    // Iterate scopes to apply first match
    token.explanation?.[0]?.scopes.forEach(scope => {
      if (tokenForeground && tokenFontStyle) return; // Skip if already matched
      const themeToken = tokenColorMap.get(scope.scopeName);
      if (themeToken) {
        tokenForeground = tokenForeground || themeToken.foreground;
        tokenFontStyle = tokenFontStyle || themeToken.fontStyle;
      }
    });

    // Returning styles
    return _reactNative.StyleSheet.flatten([baseStyle, {
      color: parseColor(token.color || tokenForeground),
      fontStyle: token.fontStyle === 2 || tokenFontStyle === 'italic' ? 'italic' : 'normal',
      fontWeight: token.fontStyle === 1 || tokenFontStyle === 'bold' ? 'bold' : 'normal',
      fontSize
    }, textStyle]);
  }, [token, fontSize, baseStyle, textStyle, tokenColorMap]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
    style: tokenStyle,
    selectable: true,
    children: token.content
  });
});
Token.displayName = 'Token';
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)(null);

  // Process theme colors once
  const tokenColorMap = (0, _react.useMemo)(() => processThemeTokenColors(theme), [theme]);
  const styles = (0, _react.useMemo)(() => {
    const backgroundColor = parseColor(theme.colors?.['editor.background']);
    const foregroundColor = parseColor(theme.colors?.['editor.foreground']);
    console.log('[SyntaxHighlighter] Theme colors:', {
      background: backgroundColor,
      foreground: foregroundColor,
      allColors: theme.colors
    });
    return _reactNative.StyleSheet.create({
      scrollView: {
        flex: 1,
        minHeight: 20
      },
      codeContainer: {
        padding: 16,
        minWidth: '100%',
        backgroundColor
      },
      lineContainer: {
        flexDirection: 'row',
        flexWrap: 'wrap'
      }
    });
  }, [theme]);
  const baseStyle = (0, _react.useMemo)(() => ({
    fontFamily: FONT_FAMILY,
    color: parseColor(theme.colors?.['editor.foreground']) || '#d8dee9'
  }), [theme]);
  (0, _react.useEffect)(() => {
    let mounted = true;
    async function highlight() {
      if (!text) {
        setTokens([]);
        return;
      }
      try {
        const highlighter = await createHighlighter({
          langs: language ? [language] : [],
          themes: [Array.isArray(theme) ? theme[0] : theme]
        });
        const result = highlighter.codeToTokens(text, {
          lang: languageId || 'plaintext',
          theme: Array.isArray(theme) ? theme[0] : theme,
          includeExplanation: true
        });
        console.log('[SyntaxHighlighter] Highlighted tokens:', result.tokens);
        if (mounted && result.tokens) {
          setTokens(result.tokens);
          setError(null);
        }
      } catch (err) {
        console.error('Syntax highlighting failed:', err);
        if (mounted) {
          setError(err instanceof Error ? err : new Error('Highlighting failed'));
          setTokens([[{
            content: text,
            color: baseStyle.color,
            offset: 0
          }]]);
        }
      }
    }
    highlight();
    return () => {
      mounted = false;
    };
  }, [text, language, languageId, theme, baseStyle.color]);
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
      horizontal: true,
      ...scrollViewProps,
      style: [styles.scrollView, scrollViewProps?.style],
      contentContainerStyle: [styles.codeContainer, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: [baseStyle, {
          fontSize
        }, textStyle],
        children: text
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [styles.scrollView, scrollViewProps?.style],
    contentContainerStyle: [styles.codeContainer, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, lineIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.lineContainer,
        children: line.map((token, tokenIndex) => {
          // Cast token to include the explanation type
          const tokenWithExplanation = token;
          return /*#__PURE__*/(0, _jsxRuntime.jsx)(Token, {
            token: tokenWithExplanation,
            fontSize: fontSize,
            textStyle: textStyle,
            baseStyle: baseStyle,
            tokenColorMap: tokenColorMap
          }, `${lineIndex}-${tokenIndex}`);
        })
      }, lineIndex))
    })
  });
};
var _default = exports.default = /*#__PURE__*/_react.default.memo(SyntaxHighlighter);
//# sourceMappingURL=SyntaxHighlighter.js.map